==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/documentdb/kotlin/inputs/GetSqlResourceSqlStoredProcedurePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.documentdb.kotlin.inputs

import com.pulumi.azurenative.documentdb.inputs.GetSqlResourceSqlStoredProcedurePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property accountName Cosmos DB database account name.
 * @property containerName Cosmos DB container name.
 * @property databaseName Cosmos DB database name.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property storedProcedureName Cosmos DB storedProcedure name.
 */
public data class GetSqlResourceSqlStoredProcedurePlainArgs(
    public val accountName: String,
    public val containerName: String,
    public val databaseName: String,
    public val resourceGroupName: String,
    public val storedProcedureName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.documentdb.inputs.GetSqlResourceSqlStoredProcedurePlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.documentdb.inputs.GetSqlResourceSqlStoredProcedurePlainArgs =
        com.pulumi.azurenative.documentdb.inputs.GetSqlResourceSqlStoredProcedurePlainArgs.builder()
            .accountName(accountName.let({ args0 -> args0 }))
            .containerName(containerName.let({ args0 -> args0 }))
            .databaseName(databaseName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .storedProcedureName(storedProcedureName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetSqlResourceSqlStoredProcedurePlainArgs].
 */
@PulumiTagMarker
public class GetSqlResourceSqlStoredProcedurePlainArgsBuilder internal constructor() {
    private var accountName: String? = null

    private var containerName: String? = null

    private var databaseName: String? = null

    private var resourceGroupName: String? = null

    private var storedProcedureName: String? = null

    /**
     * @param value Cosmos DB database account name.
     */
    @JvmName("nnbmqrykbksqbirq")
    public suspend fun accountName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.accountName = mapped
    }

    /**
     * @param value Cosmos DB container name.
     */
    @JvmName("rmvejkdfixlfqmbs")
    public suspend fun containerName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.containerName = mapped
    }

    /**
     * @param value Cosmos DB database name.
     */
    @JvmName("cquogrrvjjhpjnke")
    public suspend fun databaseName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.databaseName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("yjpuedjxvtkxgkfm")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Cosmos DB storedProcedure name.
     */
    @JvmName("vmwhyuyonckoufwb")
    public suspend fun storedProcedureName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.storedProcedureName = mapped
    }

    internal fun build(): GetSqlResourceSqlStoredProcedurePlainArgs =
        GetSqlResourceSqlStoredProcedurePlainArgs(
            accountName = accountName ?: throw PulumiNullFieldException("accountName"),
            containerName = containerName ?: throw PulumiNullFieldException("containerName"),
            databaseName = databaseName ?: throw PulumiNullFieldException("databaseName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            storedProcedureName = storedProcedureName ?: throw PulumiNullFieldException("storedProcedureName"),
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/documentdb/kotlin/inputs/GetSqlResourceSqlStoredProcedurePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.documentdb.kotlin.inputs

import com.pulumi.azurenative.documentdb.inputs.GetSqlResourceSqlStoredProcedurePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property accountName Cosmos DB database account name.
 * @property containerName Cosmos DB container name.
 * @property databaseName Cosmos DB database name.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property storedProcedureName Cosmos DB storedProcedure name.
 */
public data class GetSqlResourceSqlStoredProcedurePlainArgs(
    public val accountName: String,
    public val containerName: String,
    public val databaseName: String,
    public val resourceGroupName: String,
    public val storedProcedureName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.documentdb.inputs.GetSqlResourceSqlStoredProcedurePlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.documentdb.inputs.GetSqlResourceSqlStoredProcedurePlainArgs =
        com.pulumi.azurenative.documentdb.inputs.GetSqlResourceSqlStoredProcedurePlainArgs.builder()
            .accountName(accountName.let({ args0 -> args0 }))
            .containerName(containerName.let({ args0 -> args0 }))
            .databaseName(databaseName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .storedProcedureName(storedProcedureName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetSqlResourceSqlStoredProcedurePlainArgs].
 */
@PulumiTagMarker
public class GetSqlResourceSqlStoredProcedurePlainArgsBuilder internal constructor() {
    private var accountName: String? = null

    private var containerName: String? = null

    private var databaseName: String? = null

    private var resourceGroupName: String? = null

    private var storedProcedureName: String? = null

    /**
     * @param value Cosmos DB database account name.
     */
    @JvmName("feuevprejtfxiaod")
    public suspend fun accountName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.accountName = mapped
    }

    /**
     * @param value Cosmos DB container name.
     */
    @JvmName("xvoruhgidnqndnrk")
    public suspend fun containerName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.containerName = mapped
    }

    /**
     * @param value Cosmos DB database name.
     */
    @JvmName("ewesohcdclxanfrq")
    public suspend fun databaseName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.databaseName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("sdctvqmusltulssb")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Cosmos DB storedProcedure name.
     */
    @JvmName("gnibgnckcfxhqvyr")
    public suspend fun storedProcedureName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.storedProcedureName = mapped
    }

    internal fun build(): GetSqlResourceSqlStoredProcedurePlainArgs =
        GetSqlResourceSqlStoredProcedurePlainArgs(
            accountName = accountName ?: throw PulumiNullFieldException("accountName"),
            containerName = containerName ?: throw PulumiNullFieldException("containerName"),
            databaseName = databaseName ?: throw PulumiNullFieldException("databaseName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            storedProcedureName = storedProcedureName ?: throw PulumiNullFieldException("storedProcedureName"),
        )
}
